Calculate the Brier Score
calc_brier.RdCalculates the Brier Score, i.e. MSE of probabilities in
[0, 1] of a vector of probabilities.
The brier score attempts to account for not only wither
a prediction correctly predicts a class label at some
arbitrary evaluation cutoff, but also how close the prediction
is to predicting the label, i.e. distinguishing between
\(p = 0.51\) and \(p = 0.99\), despite both predicting
a positive class label.
Value
The Brier Score, a value in [0, 1], representing
the error in predictions, 0 being best possible score.