Fit a Generalized Boosted Regression Model
fit_gbm.RdA wrapper for fitting boosted binary regression models
for binary classification problems. Assumes a binary
"Response" in [0, 1].
Usage
fit_gbm(x, ...)
# Default S3 method
fit_gbm(x, y, ...)
# S3 method for class 'formula'
fit_gbm(formula, data, ...)Arguments
- x
A
data.framecontaining feature data (predictors). If using theformulamethod, a "Response" column should be included. The simplest way to achieve this is a call tocreate_train().- ...
Arguments passed to
gbm::gbm().- y
factor(n). If not passing a formula, a factor with true class names for each sample (row) inx.- formula
A model formula of the form: \(class ~ x1 + x2 + ...+ xn`\), (no interactions).
- data
A data frame of predictors (categorical and/or numeric).
Value
A gbm class object, as returned by gbm::gbm().
Methods (by class)
fit_gbm(default): The S3 default method forfit_gbm.fit_gbm(formula): The S3 formula method forfit_gbm.
See also
The fit*() family:
fit_kknn(),
fit_logistic(),
fit_nb()